import time
import network
import socket
import json

# Konfiguracja sieci Wi-Fi - wpisz odpowiednie dane
SSID = "..." 
PASSWORD = "..."

PORT = 80

# Pytania i odpowiedzi
pytania = [
    {"pytanie": "Który kraj ma największą liczbę aktywnych wulkanów?", "odpowiedzi": ["A: Indonezja", "B: Japonia", "C: Stany Zjednoczone", "D: Włochy"], "poprawna": "A"},
    {"pytanie": "W którym roku człowiek po raz pierwszy wylądował na Księżycu?", "odpowiedzi": ["A: 1965", "B: 1969", "C: 1971", "D: 1967"], "poprawna": "B"},
    {"pytanie": "Jak nazywa się trylogia Tolkiena, której pierwsza część to Drużyna Pierścienia?", "odpowiedzi": ["A: Hobbit", "B: Z mgły zrodzony", "C: Władca Pierścieni", "D: Wiedźmin"], "poprawna": "C"},
    {"pytanie": "Która grecka bogini była uważana za patronkę mądrości, strategii wojennej i rzemiosła, a jej symbolem była sowa?", "odpowiedzi": ["A: Hera", "B: Artemida", "C: Atena", "D: Demeter"], "poprawna": "C"},
    {"pytanie": "Jaki jest najstarszy znany instrument muzyczny na świecie?", "odpowiedzi": ["A: Harfa", "B: Lira", "C: Bęben", "D: Flet"], "poprawna": "D"},
]

# Inicjalizacja Wi-Fi
def connect_wifi():
    wlan = network.WLAN(network.STA_IF)
    wlan.active(True)
    wlan.connect(SSID, PASSWORD)
    while not wlan.isconnected():
        pass
    print("Połączono z Wi-Fi")

# Tworzenie serwera socketowego
def create_server():
    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    s.bind(("0.0.0.0", PORT))
    s.listen(5)
    print(f"Serwer nasluchuje na porcie {PORT}")
    return s

def wyslij_dane(conn, dane):
    conn.send(json.dumps(dane).encode("utf-8"))

def odbierz_dane(conn):
    data = conn.recv(1024).decode("utf-8")
    return json.loads(data)

def wyswietl_pytanie(pytanie, czas_oczekiwania):
    print(f"\nPytanie: {pytanie['pytanie']}")
    for odpowiedz in pytanie['odpowiedzi']:
        print(odpowiedz)
    
    for i in range(czas_oczekiwania, 0, -1):
        print(f"Czas na odpowiedź: {i} s ", end="\r")
        time.sleep(1)
    print("\n")

def main():
    connect_wifi()
    server = create_server()

    graczy = []
    while len(graczy) < 3:
        conn, addr = server.accept()
        print(f"Połączono z {addr}")
        graczy.append(conn)

    wyniki = {i: 0 for i in range(len(graczy))}

    for i, pytanie in enumerate(pytania):
        pytanie_dane = {
            "nr": i + 1,
            "pytanie": pytanie["pytanie"],
            "odpowiedzi": pytanie["odpowiedzi"],
        }

        # Wyświetlanie pytania na serwerze
        wyswietl_pytanie(pytanie, 3)  # 15 sekund na odpowiedź
        
        for gracz in graczy:
            wyslij_dane(gracz, pytanie_dane)

        odpowiedzi = {}
        for j, gracz in enumerate(graczy):
            odpowiedzi[j] = odbierz_dane(gracz)["odpowiedz"]

        print(f"Pytanie {i + 1}: {pytanie['pytanie']}")
        for gracz_id, odp in odpowiedzi.items():
            poprawna = pytanie["poprawna"]
            wynik = 1 if odp == poprawna else 0
            wyniki[gracz_id] += wynik
            print(f"Gracz {gracz_id}: {odp} ({'Poprawna' if wynik else 'Niepoprawna'})")

    print("Podsumowanie wyników:")
    for gracz_id, punkty in wyniki.items():
        print(f"Gracz {gracz_id}: {punkty} pkt")
        wyslij_dane(graczy[gracz_id], {"wynik": punkty})

    for gracz in graczy:
        gracz.close()

if __name__ == "__main__":
    main()

